#!/usr/bin/env python3

import os
import pwd
import sys

destdir = os.environ.get('DESTDIR')
prefix = os.environ['MESON_INSTALL_DESTDIR_PREFIX']

def destdir_path(p):
    if os.path.isabs(p):
        if destdir is None:
            return p
        else:
            return os.path.join(destdir, os.path.relpath(p, '/'))
    else:
        return os.path.join(prefix, p)

bindir = destdir_path(sys.argv[1])
pkgdatadir = destdir_path(sys.argv[2])
pkglibdir = destdir_path(sys.argv[3])
pkgsysconfdir = destdir_path(sys.argv[4])
polkitd_user = sys.argv[5]

try:
    polkitd_uid = pwd.getpwnam(polkitd_user).pw_uid
except KeyError:
    polkitd_uid = None

dst = os.path.join(bindir, 'pkexec')

if os.geteuid() == 0:
    os.chown(dst, 0, -1)
    os.chmod(dst, 0o4755)
else:
    print(
        'Owner and mode of {} need to be setuid root (04755) after '
        'installation'.format(
            dst,
        )
    )

dst_dirs = [
    os.path.join(pkgsysconfdir, 'rules.d'),
    os.path.join(pkgdatadir, 'rules.d')
]

for dst in dst_dirs:
    if not os.path.exists(dst):
        os.makedirs(dst, mode=0o700)
        if os.geteuid() == 0 and polkitd_uid is not None:
            os.chown(dst, polkitd_uid, -1)
        else:
            print(
                'Owner of {} needs to be set to {} after installation'.format(
                    dst, polkitd_user,
                )
            )

# polkit-agent-helper-1 need to be setuid root because it's used to
# authenticate not only the invoking user, but possibly also root
# and/or other users.
dst = os.path.join(pkglibdir, 'polkit-agent-helper-1')

if os.geteuid() == 0:
    os.chown(dst, 0, -1)
    os.chmod(dst, 0o4755)
else:
    print(
        'Owner and mode of {} need to be setuid root (04755) after '
        'installation'.format(
            dst,
        )
    )



#!/usr/bin/env python

# Copyright (C) 2009 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General
# Public License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA 02111-1307, USA.
#
# Author: David Zeuthen <davidz@redhat.com>

# Simple example showing how to access the Authority via D-Bus calls
#

import dbus

bus = dbus.SystemBus()
proxy = bus.get_object('org.freedesktop.PolicyKit1', '/org/freedesktop/PolicyKit1/Authority')
authority = dbus.Interface(proxy, dbus_interface='org.freedesktop.PolicyKit1.Authority')

system_bus_name = bus.get_unique_name()

subject = ('system-bus-name', {'name' : system_bus_name})
action_id = 'org.freedesktop.policykit.exec'
details = {}
flags = 1            # AllowUserInteraction flag
cancellation_id = '' # No cancellation id

result = authority.CheckAuthorization(subject, action_id, details, flags, cancellation_id)

print result



#!/usr/bin/python3

# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation; either version 3 of the License, or (at your option) any
# later version.  See http://www.gnu.org/copyleft/lgpl.html for the full text
# of the license.

__author__ = 'Bastien Nocera'
__email__ = 'hadess@hadess.net'
__copyright__ = '(c) 2020 Red Hat Inc.'
__license__ = 'LGPL 3+'

import unittest
import sys
import subprocess
import dbus
import dbus.mainloop.glib
import dbusmock
import os
import time

dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)

class TestPolkitBackendJsAuthority(dbusmock.DBusTestCase):
    '''Test polkitbackendjsauthoritytest'''

    @classmethod
    def setUpClass(klass):
        klass.start_system_bus()
        klass.mocklibc_path = None

        if 'TOP_BUILD_DIR' in os.environ:
            klass.top_build_dir = os.environ['TOP_BUILD_DIR']
            klass.mocklibc_path = klass.top_build_dir  + '/subprojects/mocklibc-1.0/bin/mocklibc'

        # suppose autotools over meson
        if not os.path.exists(klass.mocklibc_path):
            klass.top_build_dir = '../../'
            klass.mocklibc_path = klass.top_build_dir + '/test/mocklibc/bin/mocklibc'
        print ('Top build dir: %s' % klass.top_build_dir)
        print ('mocklibc path: %s' % klass.mocklibc_path)
        assert(os.path.exists(klass.mocklibc_path))

        # WORKAROUND - unzipped mocklibc does not preserve file permissions
        os.chmod(klass.mocklibc_path, 0o755)

        klass.top_src_dir = os.path.dirname(os.path.realpath(__file__)) + '/../../'
        if 'TOP_SRC_DIR' in os.environ:
            klass.top_src_dir = os.environ['TOP_SRC_DIR']
        print ('Top source dir: %s' % klass.top_src_dir)

        os.environ['POLKIT_TEST_DATA'] = klass.top_src_dir + '/test/data'
        print ('Polkit test data dir: %s' % os.environ['POLKIT_TEST_DATA'])

        os.environ['MOCK_PASSWD'] = klass.top_src_dir + '/test/data/etc/passwd'
        print ('Mock password file: %s' % os.environ['MOCK_PASSWD'])
        os.environ['MOCK_GROUP'] = klass.top_src_dir + '/test/data/etc/group'
        print ('Mock group file: %s' % os.environ['MOCK_GROUP'])
        os.environ['MOCK_NETGROUP'] = klass.top_src_dir + '/test/data/etc/netgroup'
        print ('Mock netgroup file: %s' % os.environ['MOCK_NETGROUP'])

    def test_polkitbackendjsauthoritytest(self):
        # Add '; exit 0' at the end of the cmd line if launching fails and you
        # want to capture the error output
        test_path = self.top_build_dir + '/test/polkitbackend/test-polkitbackendjsauthority'

        if not os.path.exists(test_path):
            print('\n %s... not found' % test_path)
            test_path = self.top_build_dir + '/test/polkitbackend/polkitbackendjsauthoritytest'

        out = subprocess.check_output(self.mocklibc_path + ' ' + test_path,
                                      stderr=subprocess.STDOUT,
                                      shell=True,
                                      universal_newlines=True)
        print(out)

if __name__ == '__main__':
    # avoid writing to stderr
    unittest.main(testRunner=unittest.TextTestRunner(stream=sys.stdout, verbosity=2))
